#[repr(C)]pub enum ArrayError {
AllocationError = 0,
LengthLimitExceeded = 1,
}Expand description
Represents a general issue that can occure when dealing with arrays.
Variants
AllocationError = 0
The underlying allocator returned an error, likely due to out of memory.
LengthLimitExceeded = 1
Tried to initialize an array or push to array beyond its internal limit.