#[repr(u8)]pub enum ArrayTryCloneError {
ArrayError(ArrayError),
ItemCloningError = 1,
}Variants
ArrayError(ArrayError)
The underlying allocator returned an error, likely due to out of memory.
ItemCloningError = 1
Tried to clone internal item in the array, but cloning failed.